@@ -1,8 +1,9 @@
-from pathlib import Path
+import datetime
 import os
-
+from pathlib import Path
 
 SAGASU_WORKDIR = f"{os.getenv('HOME')}/.sagasu"
+JST = datetime.timezone(datetime.timedelta(hours=+9), "JST")
 
 
 def mkdir_p(file_path):
